( cd usr/bin ; rm -rf bibtex )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/bibtex bibtex )
( cd usr/lib/texmf/bibtex/bib ; rm -rf README )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/README README )
( cd usr/lib/texmf/bibtex/bib ; rm -rf asi.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/asi.bib asi.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf btxdoc.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/btxdoc.bib btxdoc.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf byrnes.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/byrnes.bib byrnes.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf ep.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/ep.bib ep.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf epodd.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/epodd.bib epodd.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf institut.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/institut.bib institut.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf internet.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/internet.bib internet.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf journal.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/journal.bib journal.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf kbmath.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/kbmath.bib kbmath.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf litprog.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/litprog.bib litprog.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf master.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/master.bib master.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf mrabbrev.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/mrabbrev.bib mrabbrev.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf postscri.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/postscri.bib postscri.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf publish.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/publish.bib publish.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf reading.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/reading.bib reading.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf standard.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/standard.bib standard.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf texbook1.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/texbook1.bib texbook1.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf texbook2.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/texbook2.bib texbook2.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf texgraph.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/texgraph.bib texgraph.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf texjourn.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/texjourn.bib texjourn.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf texnique.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/texnique.bib texnique.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf tugboat.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/tugboat.bib tugboat.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf type.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/type.bib type.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf unix.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/unix.bib unix.bib )
( cd usr/lib/texmf/bibtex/bib ; rm -rf xampl.bib )
( cd usr/lib/texmf/bibtex/bib ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bib/xampl.bib xampl.bib )
( cd usr/lib/texmf/bibtex/bst ; rm -rf abbrv.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/abbrv.bst abbrv.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf acm.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/acm.bst acm.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf alpha.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/alpha.bst alpha.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf apalike.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/apalike.bst apalike.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf ieeetr.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/ieeetr.bst ieeetr.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf plain.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/plain.bst plain.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf siam.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/siam.bst siam.bst )
( cd usr/lib/texmf/bibtex/bst ; rm -rf unsrt.bst )
( cd usr/lib/texmf/bibtex/bst ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/bst/unsrt.bst unsrt.bst )
( cd usr/lib/texmf/bibtex/doc ; rm -rf bibshare )
( cd usr/lib/texmf/bibtex/doc ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/doc/bibshare bibshare )
( cd usr/lib/texmf/bibtex/doc ; rm -rf btxbst.doc )
( cd usr/lib/texmf/bibtex/doc ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/doc/btxbst.doc btxbst.doc )
( cd usr/lib/texmf/bibtex/doc ; rm -rf btxdoc.bbl )
( cd usr/lib/texmf/bibtex/doc ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/doc/btxdoc.bbl btxdoc.bbl )
( cd usr/lib/texmf/bibtex/doc ; rm -rf btxdoc.tex )
( cd usr/lib/texmf/bibtex/doc ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/doc/btxdoc.tex btxdoc.tex )
( cd usr/lib/texmf/bibtex/doc ; rm -rf btxdoc.xua )
( cd usr/lib/texmf/bibtex/doc ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/doc/btxdoc.xua btxdoc.xua )
( cd usr/lib/texmf/bibtex/doc ; rm -rf btxhak.tex )
( cd usr/lib/texmf/bibtex/doc ; ln -sf /cdrom/live/usr/lib/texmf/bibtex/doc/btxhak.tex btxhak.tex )
( cd usr/man/preformat/cat1 ; rm -rf bibtex.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/bibtex.1.gz bibtex.1.gz )
